require 'active_record'

module MerryGoRound
  # Aggregation is the ActiveRecord store for aggregated data points. You should
  # never create aggregations directly unless you know what you're doing.
  class Aggregation < ActiveRecord::Base
    attr_accessible :key, :value, :timestamp, :granularity, :parent_id

    belongs_to :parent, class_name: 'MerryGoRound::Aggregation'
    has_many :children, class_name: 'MerryGoRound::Aggregation', foreign_key: :parent_id

    validates :key, :value, :timestamp, :granularity, presence: true
    validate :valid_granularity

    def self.table_name
      'merry_go_round_aggregations'
    end

    def self.for_key(key, granularity = MerryGoRound.granularities.first)
     where('key = ? AND granularity = ?', key, granularity)
    end

  private

    def valid_granularity
      errors.add(:message, 'is not a valid granularity') unless MerryGoRound.granularities.include?(self.granularity.to_sym)
    end
  end
end
